@@ -39,6 +39,9 @@ class BaseUploadForm(forms.ModelForm):
         self.clean_lines = []
         for line_dict in self.reader:
             for key, value in line_dict.iteritems():
+                # strip blank spaces
+                value = value.strip()
+                line_dict[key] = value
                 if key == 'consign':
                     if value == '0':
                         value = False
